import { getTranslations } from "next-intl/server";

import Footer from "@/components/layout/footer";
import Header from "@/components/layout/header-2/header-2";
import MaintenanceRequestForm from "@/components/sections/maintenance-request/maintenance-request-form";
import PageBreadcrump from "@/components/shared/testing/page-breadcrump";
import ShinyButton from "@/components/ui/shiny-button";
import { LocaleParams } from "@/types/params";

async function ServicesPage({ params }: { params: LocaleParams }) {
  const { locale } = await params;

  const t = await getTranslations("MaintenanceRequest");

  const breadcrumbItems = [
    {
      href: "/",
      label: {
        en: "Home",
        ar: "الرئيسية",
      },
    },
    {
      href: "/maintenance-request",
      label: {
        en: "Maintenance request",
        ar: "طلب صيانة",
      },
    },
  ];

  return (
    <section>
      <Header  />
      <PageBreadcrump
        locale={locale}
        backgroundUrl="/heros/maintenance-request.png"
        subtitle={{
          en: "Bin Taleb Company",
          ar: "شركة بن طالب",
        }}
        title={{
          en: "Maintenance request",
          ar: "طلب صيانة",
        }}
        breadcrumbItems={breadcrumbItems}
      />
      <div className="mx-auto mb-12 max-w-7xl px-2 sm:px-2 md:px-4 lg:px-4 xl:px-24">
        <div className="mb-5 mt-12 flex items-center justify-center gap-6">
          <ShinyButton
            className="rounded-[999px] bg-custom-primary-accent px-8 py-3 text-white"
            style={{
              border: "1px solid #DEDEDE",
              boxShadow: "6px 6px 12px 0px #0000004D",
            }}
          >
            <p className="text-white">{t("ImmediateMaintenanceRequest")}</p>
          </ShinyButton>
          <ShinyButton
            className="rounded-[999px] bg-[#606676] px-8 py-3 text-white"
            style={{
              border: "1px solid #DEDEDE",
              boxShadow: "6px 6px 12px 0px #0000004D",
            }}
          >
            <p className="text-white">{t("RegularMaintenanceRequest")}</p>
          </ShinyButton>
        </div>

        <MaintenanceRequestForm />
      </div>
      <Footer   />
    </section>
  );
}

export default ServicesPage;
